@@ -1,3 +1,4 @@
+from __future__ import annotations
 from typing import *
 from typing import NoReturn # py 3.6
 if TYPE_CHECKING:
@@ -26,14 +27,15 @@ def unique(gen: Iterable[T], fn:Callable[[T], Any] = hash) -> Iterable[T]:
 def assert_never(x: NoReturn) -> NoReturn:
 	assert False, f'Unhandled type: {type(x).__name__}'
 
-def limit_query(query: 'Query', rows: int, dialect: 'SQLDialect') -> 'Query':
+def limit_query(query: Query, rows: int, dialect: SQLDialect) -> Query:
 	from .api import Q
 	from .models.dialect import Limit
 	if dialect.limit is Limit.limit:
-		return Q(f"select * from {query} limit {rows}")
+		query_str = f"select * from {query} limit {rows}"
 	elif dialect.limit is Limit.top_n:
-		return Q(f"select top({rows}) * from {query}")
+		query_str = f"select top({rows}) * from {query}"
 	elif dialect.limit is Limit.ansi:
-		return Q(f"select * from {query} fetch first {rows} rows only")
+		query_str = f"select * from {query} fetch first {rows} rows only"
 	else:
-		assert_never(dialect.limit)
\ No newline at end of file
+		assert_never(dialect.limit)
+	return Q(query_str)
\ No newline at end of file
