@@ -1,6 +1,5 @@
 # mypy: implicit-reexport
 from .._.renderer.parameters import (
-	ScalarParameterValue,
 	SQL,
 
 	ParamList,
@@ -12,3 +11,4 @@ from .._.renderer.parameters import (
 	ColonNumeric,
 	DollarNumeric
 )
+from .._.models.query import AutoKey
